<?php

namespace Drupal\devel_tomsaw\Drush\Commands;

use Drush\Attributes as CLI;
use Drush\Commands\DrushCommands;
use Drupal\memcache\Driver\MemcacheDriverFactory;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A Drush commandfile.
 *
 * In addition to this file, you need a drush.services.yml
 * in root of your module, and a composer.json file that provides the name
 * of the services file to use.
 */
final class DevelTomsawCommands extends DrushCommands {

  /**
   * Constructs a DevelTomsawCommands object.
   */
  public function __construct(
    private readonly MemcacheDriverFactory $memcacheFactory
  ) {
    parent::__construct();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('memcache.factory')
    );
  }

  #[CLI\Command(name: 'devel:script')]
  public function remap_ui_styles() {
    \Drupal::service('generic_layout.manager')->updateLayoutSettings(
      function (\Drupal\layout_builder\Section $section): void {
        $ui_styles = $section->getThirdPartySetting('ui_styles', 'selected');

        $replace_keys = [
          'text_size' => 'font_size'
        ];

        $replace_values = [
          'ts-' => 'fs-',
          // 'fs-' => 'ts-',
          // 'ch-' => 'hc-',
          // 'cb-' => 'bc-',
          // 'cr-' => 'rc-',
          // 'padding_inline' => 'padding_inline_container',
          // 'headings' => 'heading',
          // 'text_color' => 'color',
          // 'heading_color' => 'color_heading',
        ];

        foreach ($ui_styles as $key => &$value) {
          foreach ($replace_keys as $from => $to) {
            $key_new = str_replace($from, $to, $key);

            if ($key_new != $key) {
              unset($ui_styles[$key]);
              $ui_styles[$key_new] = $value;
            }
          }
          foreach ($replace_values as $from => $to) {
            $value = str_replace($from, $to, $value);
          }
        }

        $section->setThirdPartySetting('ui_styles', 'selected', $ui_styles);
      }
    );
  }

  #[CLI\Command(name: 'cache:memcache-flush', aliases: ['cmf'])]
  public function flushMemcache() {
    // @todo check if memcache exists!
    $this->memcacheFactory->get('default')->flush();
    $this->logger()->success("Memcache flushed");
  }
}
